@@ -149,7 +149,7 @@ to? To                 @op @A2  @P9
 =~  Match              @op @A2   @P9
 
 |  Lor                  @op @top  @P11
-%% Fmt                 @op @2    @P12 @A2
+%% Fmt                 @op @2    @P12
 
 << Lshift              @op @2    @P15
 >> Rshift              @op @2    @P15
