@@ -191,13 +191,13 @@ KNHAPI(void) knh_ResultSet_initData(Ctx *ctx, ResultSet *o)
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(void) knh_ResultSet_setInt(Ctx *ctx, ResultSet *o, size_t n, knh_int_t value)
+KNHAPI(void) knh_ResultSet_setInt(Ctx *ctx, ResultSet *o, size_t n, knh_integer_t value)
 {
 	KNH_ASSERT(n < DP(o)->column_size);
-	knh_bytes_t t = {(knh_uchar_t*)(&value), sizeof(knh_int_t)};
-	DP(o)->column[n].ctype = knh_ResultSet_CTYPE__int;
+	knh_bytes_t t = {(knh_uchar_t*)(&value), sizeof(knh_integer_t)};
+	DP(o)->column[n].ctype = knh_ResultSet_CTYPE__integer;
 	DP(o)->column[n].start = knh_Bytes_size(DP(o)->databuf);
-	DP(o)->column[n].len = sizeof(knh_int_t);
+	DP(o)->column[n].len = sizeof(knh_integer_t);
 	knh_Bytes_write(ctx, DP(o)->databuf, t);
 }
 
@@ -217,18 +217,6 @@ KNHAPI(void) knh_ResultSet_setFloat(Ctx *ctx, ResultSet *o, size_t n, knh_float_
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(void) knh_ResultSet_setInt64(Ctx *ctx, ResultSet *o, size_t n, knh_int64_t value)
-{
-	KNH_ASSERT(n < DP(o)->column_size);
-	knh_bytes_t t = {(knh_uchar_t*)(&value), sizeof(knh_int64_t)};
-	DP(o)->column[n].ctype = knh_ResultSet_CTYPE__int64;
-	DP(o)->column[n].start = knh_Bytes_size(DP(o)->databuf);
-	DP(o)->column[n].len = sizeof(knh_int64_t);
-	knh_Bytes_write(ctx, DP(o)->databuf, t);
-}
-
-/* ------------------------------------------------------------------------ */
-
 KNHAPI(void) knh_ResultSet_setBytes(Ctx *ctx, ResultSet *o, size_t n, knh_bytes_t t)
 {
 	KNH_ASSERT(n < DP(o)->column_size);
@@ -252,19 +240,17 @@ KNHAPI(void) knh_ResultSet_setNULL(Ctx *ctx, ResultSet *o, size_t n)
 
 /* ------------------------------------------------------------------------ */
 
-knh_int_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n)
+knh_integer_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n)
 {
 	KNH_ASSERT(n < DP(o)->column_size);
 	char *p = knh_Bytes_tochar(DP(o)->databuf) + DP(o)->column[n].start;
 	switch(DP(o)->column[n].ctype) {
 	case knh_ResultSet_CTYPE__null :
 		return 0;
-	case knh_ResultSet_CTYPE__int :
-		return (knh_int_t)(*((knh_int_t*)p));
+	case knh_ResultSet_CTYPE__integer :
+		return (knh_integer_t)(*((knh_integer_t*)p));
 	case knh_ResultSet_CTYPE__float :
-		return (knh_int_t)(*((knh_float_t*)p));
-	case knh_ResultSet_CTYPE__int64 :
-		return (knh_int_t)(*((knh_int64_t*)p));
+		return (knh_integer_t)(*((knh_float_t*)p));
 	case knh_ResultSet_CTYPE__bytes :
 		TODO();
 //		return knh_bytes_toint(B2(p, DP(o)->column[n].len));
@@ -281,12 +267,10 @@ knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n)
 	switch(DP(o)->column[n].ctype) {
 	case knh_ResultSet_CTYPE__null :
 		return 0.0;
-	case knh_ResultSet_CTYPE__int :
-		return (knh_float_t)(*((knh_int_t*)p));
+	case knh_ResultSet_CTYPE__integer :
+		return (knh_float_t)(*((knh_integer_t*)p));
 	case knh_ResultSet_CTYPE__float :
 		return (knh_float_t)(*((knh_float_t*)p));
-	case knh_ResultSet_CTYPE__int64 :
-		return (knh_float_t)(*((knh_int64_t*)p));
 	case knh_ResultSet_CTYPE__bytes :
 		TODO();
 //		return knh_bytes_tofloat(B2(p, DP(o)->column[n].len));
@@ -294,26 +278,6 @@ knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n)
 	return 0.0;
 }
 
-/* ------------------------------------------------------------------------ */
-
-knh_int64_t knh_ResultSet_getInt64(Ctx *ctx, ResultSet *o, size_t n)
-{
-	char *p = knh_Bytes_tochar(DP(o)->databuf) + DP(o)->column[n].start;
-	switch(DP(o)->column[n].ctype) {
-	case knh_ResultSet_CTYPE__null :
-		return 0L;
-	case knh_ResultSet_CTYPE__int :
-		return (knh_int64_t)(*((knh_int_t*)p));
-	case knh_ResultSet_CTYPE__float :
-		return (knh_int64_t)(*((knh_float_t*)p));
-	case knh_ResultSet_CTYPE__int64 :
-		return (knh_int64_t)(*((knh_int64_t*)p));
-	case knh_ResultSet_CTYPE__bytes :
-		TODO();
-//		return knh_bytes_toint64(B2(p, DP(o)->column[n].len));
-	}
-	return 0L;
-}
 
 ///* ------------------------------------------------------------------------ */
 ///* @method Any ResultSet.get(Int! n) */
@@ -365,11 +329,11 @@ knh_int64_t knh_ResultSet_getInt64(Ctx *ctx, ResultSet *o, size_t n)
 //		{
 //			char *p = knh_Bytes_tochar(DP(o)->databuf) + DP(o)->column[n].start;
 //			switch(DP(o)->column[n].ctype) {
-//				case knh_ResultSet_CTYPE__int :
+//				case knh_ResultSet_CTYPE__integer :
 //					return new_Int(ctx, (knh_int_t)(*((knh_int_t*)p)));
 //				case knh_ResultSet_CTYPE__float :
 //					return new_Float(ctx, (knh_float_t)(*((knh_float_t*)p)));
-//				case knh_ResultSet_CTYPE__int64 :
+//				case knh_ResultSet_CTYPE__integer64 :
 //					TODO();
 //					return KNH_NULL;
 //				case knh_ResultSet_CTYPE__bytes :
@@ -398,16 +362,12 @@ void knh_ResultSet__dump(Ctx *ctx, ResultSet *o, OutputStream *w, String *m)
 			case knh_ResultSet_CTYPE__null :
 				knh_write(ctx, w, STEXT("null"));
 				break;
-			case knh_ResultSet_CTYPE__int :
+			case knh_ResultSet_CTYPE__integer :
 				knh_write__i(ctx, w, (knh_int_t)(*((knh_int_t*)p)));
 				break;
 			case knh_ResultSet_CTYPE__float :
 				knh_write__f(ctx, w, (knh_float_t)(*((knh_float_t*)p)));
 				break;
-			case knh_ResultSet_CTYPE__int64 :
-				TODO();
-				/*knh_write__l(ctx, w, (knh_int64_t)(*((knh_int64_t*)p))); */
-				break;
 			case knh_ResultSet_CTYPE__bytes :
 				knh_write(ctx, w, B2(p, DP(o)->column[n].len));
 				break;
