@@ -117,10 +117,11 @@ METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp)
 
 void knh_System__k(Ctx *ctx, System *o, OutputStream *w, String *m)
 {
+	char *_PREVIEW_ = (KONOHA_BUILDID % 2 == 1) ? " _PREVIEW_" : "";
 #ifdef KONOHA_UNDER_GPL2
-	knh_printf(ctx, w, "Konoha %s-GPL2 (#%d, %s, %s)\n", KONOHA_VERSION, KONOHA_BUILDID, __DATE__, __TIME__);
+	knh_printf(ctx, w, "Konoha %s%s GPL2 (#%d, %s, %s)\n", KONOHA_VERSION, _PREVIEW_, KONOHA_BUILDID, __DATE__, __TIME__);
 #else
-	knh_printf(ctx, w, "Konoha %s (#%d, %s, %s)\n" TERM_INIT, KONOHA_VERSION, KONOHA_BUILDID, __DATE__, __TIME__);
+	knh_printf(ctx, w, "Konoha %s%s (#%d, %s, %s)\n" TERM_INIT, KONOHA_VERSION, _PREVIEW_, KONOHA_BUILDID, __DATE__, __TIME__);
 #endif
 	knh_printf(ctx, w, "[%s] on %s (%d, %s)\n", KONOHA_CC_VERSION, KONOHA_OS, sizeof(void*) * 8, konoha_encoding());
 	knh_write__s(ctx, w, "Options:");
