@@ -582,8 +582,10 @@ void knh_Token_constTSTR(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns)
 		knh_Token_toCONST(o);
 	}
 	else {
-		TODO();
-		knh_Token_toCONST(o);
+		if(DP(o)->tt_next == TT_ADD || DP(o)->tt_next == TT_FMT) {
+			TODO();
+		}
+		knh_Token_setCONST(ctx, o, new_Object_parseOf(ctx, (String*)DP(o)->data));
 	}
 }
 
