@@ -1334,6 +1334,13 @@ Term *new_TermEXPR(Ctx *ctx, knh_tokens_t *tc, int lr)
 					knh_Stmt_add(ctx, stmt, new_TermEXPR(ctx, tc, KNH_RVALUE));
 					return TM(stmt);
 				}
+				else if(idx == tc->e - 1) {
+					Stmt *stmt = new_Stmt(ctx, 0, STT_OP);
+					knh_Stmt_add(ctx, stmt, TM(ts[idx]));
+					tc->e = idx;
+					knh_Stmt_add(ctx, stmt, new_TermEXPR(ctx, tc, KNH_RVALUE));
+					return TM(stmt);
+				}
 				else {
 					knh_Token_perror(ctx, ts[idx], KMSG_UOP1);
 					SP(ts[idx])->tt = TT_ERR; return TM(ts[idx]);
